@@ -497,12 +497,14 @@ class CodeBuildProject(
         project: aws_cdk.aws_codebuild.IProject,
         *,
         event: typing.Optional[aws_cdk.aws_events.RuleTargetInput] = None,
+        event_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
     ) -> None:
         """
         :param project: -
         :param event: The event to send to CodeBuild. This will be the payload for the StartBuild API. Default: - the entire EventBridge event
+        :param event_role: The role to assume before invoking the target (i.e., the codebuild) when the given rule is triggered. Default: - a new role will be created
         """
-        props = CodeBuildProjectProps(event=event)
+        props = CodeBuildProjectProps(event=event, event_role=event_role)
 
         jsii.create(CodeBuildProject, self, [project, props])
 
@@ -523,21 +525,25 @@ class CodeBuildProject(
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-events-targets.CodeBuildProjectProps",
     jsii_struct_bases=[],
-    name_mapping={"event": "event"},
+    name_mapping={"event": "event", "event_role": "eventRole"},
 )
 class CodeBuildProjectProps:
     def __init__(
         self,
         *,
         event: typing.Optional[aws_cdk.aws_events.RuleTargetInput] = None,
+        event_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
     ) -> None:
         """Customize the CodeBuild Event Target.
 
         :param event: The event to send to CodeBuild. This will be the payload for the StartBuild API. Default: - the entire EventBridge event
+        :param event_role: The role to assume before invoking the target (i.e., the codebuild) when the given rule is triggered. Default: - a new role will be created
         """
         self._values: typing.Dict[str, typing.Any] = {}
         if event is not None:
             self._values["event"] = event
+        if event_role is not None:
+            self._values["event_role"] = event_role
 
     @builtins.property
     def event(self) -> typing.Optional[aws_cdk.aws_events.RuleTargetInput]:
@@ -550,6 +556,15 @@ class CodeBuildProjectProps:
         result = self._values.get("event")
         return result
 
+    @builtins.property
+    def event_role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+        """The role to assume before invoking the target (i.e., the codebuild) when the given rule is triggered.
+
+        :default: - a new role will be created
+        """
+        result = self._values.get("event_role")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
